
// MiniCasino class for CS 171 Project 1 (do not update)
// Author:  John Paul Vergara

import java.util.Random;

public class MiniCasino
{
	private SlotMachine A;
	private SlotMachine B;
	private double expAGiven;
	private double expBGiven;
	
	public MiniCasino( double expA, double expB, long seed )
	{
		expAGiven = expA;
		expBGiven = expB;
		// negative expected payoff means "unknown"
		// in this case, expected payoff is randonly generated
		if ( expA < 0 || expB < 0 )
		{
			Random g = new Random( seed );
			if ( expA < 0 )
			{
				expA = 0.6 + g.nextDouble();
			}
			if ( expB < 0 )
			{
				expB = 0.6 + g.nextDouble();
			}			
		}
		// make the seeds for the slot machines dependent on the seed parameter
		A = new SlotMachine( expA, seed+1 );
		B = new SlotMachine( expB, seed+2 );
	}
	
	public String play( String decision )
	{
		if ( decision.equals( "NO" ) )
		{
			return "";
		}
		else if ( decision.equals( "A" ) )
		{
			return "" + A.play();
		}
		else if ( decision.equals( "B" ) )
		{
			return "" + B.play();
		}
		else if ( decision.equals( "AB" ) )
		{
			return "" + A.play() + " " + B.play();
		}
		else
		{
			return "ERROR";
		}
	}
	
	public double getexpA()
	{
		return expAGiven;
	}
	
	public double getexpB()
	{
		return expBGiven;
	}
	
}

class SlotMachine
{
	double zero;
	double one;
	double five;
	
	Random generator;
	
	public SlotMachine( double exp, long seed )
	{
		zero = 0.60;
		one = 0.95;
		
		// exp = 0.6 x 0 + 0.35 x 1 + f x 5 + (0.05-f) x 100
		// f = (5.35-exp)/95
		
		double f = ( 5.35 - exp )/95;
		five = 0.95 + f;
		generator = new Random( seed );
		
	}
	public int play()
	{
		double randomNum = generator.nextDouble();
		if ( randomNum < zero )
		{
			return 0;
		}
		else if ( randomNum < one )
		{
			return 1;
		}
		else if ( randomNum < five )
		{
			return 5;
		}
		else
		{
			return 100;
		}
	}
}